@@ -7,9 +7,10 @@ use Time::HiRes qw(sleep);
 
 my $fb = Graphics::Framebuffer->new('SPLASH' => 1,'SHOW_ERRORS'=>1);
 
-my $adj = 1920 / $fb->{'VXRES'};
+my $adj = $fb->{'XRES'} / 1920;
 
 $fb->cls();
+# $fb->or_mode();
 
 foreach my $font (sort(keys %{$fb->{'FONTS'}})) {
     $fb->cls();
@@ -20,7 +21,8 @@ foreach my $font (sort(keys %{$fb->{'FONTS'}})) {
         'text'         => $font,
         'font_path'    => $fb->{'FONTS'}->{$font}->{'path'},
         'color'        => 'FFFFFFFF',
-        'height'       => 150 * $adj
+        'height'       => 150 * $adj,
+        'antialias'    => 1
     };
     $fb->ttf_print(
         $fb->ttf_print($tprint)
