@@ -52,6 +52,7 @@ my $YY            = $screen_height;
 my $center_x      = $XX / 2;
 my $center_y      = $YY / 2;
 my $factor        = 5;
+my $images_path   = (-e 'images/GFB.png') ? 'images' : 'examples/images';
 
 $F->cls('OFF');
 # if (0){
@@ -83,7 +84,7 @@ print_it($F,'Color Mapping Test -> Red-Green-Blue');
             'width'  => $XX * .75,
             'height' => ($YY - $F->{'Y_CLIP'}) * .75,
             'center' => 3,
-            'file'   => 'images/testpattern.jpg'
+            'file'   => "$images_path/testpattern.jpg"
         }
     );
     $F->blit_write($image);
@@ -455,7 +456,7 @@ while (time < $s) {
                 'y'            => $y,
                 'height'       => $h,
                 'wscale'       => $ws,
-                'color'        => sprintf('%02x%02x%02x%02x', int(rand(256)), int(rand(256)), int(rand(256)),int(rand(256))),
+                'color'        => sprintf('%02x%02x%02x%02x', int(rand(256)), int(rand(256)), int(rand(256)),255),
                 'text'         => 'GFB',
                 'bounding_box' => 1,
                 'center'       => 3
@@ -556,7 +557,7 @@ print_it($F, 'Testing Image load (different sizes)');
                 'width'  => rand($XX),
                 'height' => rand($YY - $F->{'Y_CLIP'}),
                 'center' => 3,
-                'file'   => 'images/GFB.png'
+                'file'   => "$images_path/GFB.png"
             }
         );
         if (defined($blank)) {
@@ -574,7 +575,7 @@ print_it($F, 'Testing Image load (different sizes)');
             'width'  => $XX,
             'height' => ($YY - $F->{'Y_CLIP'}),
             'center' => 3,
-            'file'   => 'images/GFB.png'
+            'file'   => "$images_path/GFB.png"
         }
     );
     if (defined($blank)) {
@@ -594,7 +595,7 @@ $image = $F->load_image(
         'y'      => 0,
         'width'  => int($XX/3),
         'height' => int($YY/3),
-        'file'   => 'images/RWBY_Logo.png'
+        'file'   => "$images_path/RWBY_Logo.png"
     }
 );
 $s = time + $factor;
@@ -604,7 +605,7 @@ while (time < $s) {
     $F->blit_write($image);
 }
 
-print_it($F, "Testing Image rotate");
+print_it($F, 'Loading "RWBY_Oh_No.jpg" for Rotate Test','FFFF00FF');
 if ($YY<=240) {
     $image = $F->load_image(
         {
@@ -612,7 +613,7 @@ if ($YY<=240) {
             'y'      => 0,
             'width'  => int($YY*.7),
 #            'height' => int($YY/3),
-            'file'   => 'images/RWBY_Oh_No.jpg'
+            'file'   => "$images_path/RWBY_Oh_No.jpg"
         }
     );
 } else {
@@ -622,14 +623,16 @@ if ($YY<=240) {
             'y'      => 0,
             'width'  => int($XX * .4),
             'height' => int($YY * .4),
-            'file'   => 'images/RWBY_Oh_No.jpg'
+            'file'   => "$images_path/RWBY_Oh_No.jpg"
         }
     );
 }
 $angle = 0;
 {
+    print_it($F, 'Counter-Clockwise Rotate Test');
     $s = time + ($factor * 2);
-    while (time < $s) {
+    my $count = 0;
+    while (time < $s || $count < 6) {
         my $rot = $F->blit_transform(
             {
                 'rotate' => {
@@ -645,12 +648,15 @@ $angle = 0;
 
         $angle += 5;
         $angle = 0 if ($angle >= 360);
+        $count++;
     }
 }
 $angle = 0;
 {
+    print_it($F, 'Clockwise Rotate Test');
     $s = time + ($factor * 2);
-    while (time < $s) {
+    my $count = 0;
+    while (time < $s || $count < 6) {
         my $rot = $F->blit_transform(
             {
                 'rotate' => {
@@ -666,22 +672,25 @@ $angle = 0;
 
         $angle -= 5;
         $angle = 0 if ($angle <= -360);
+        $count++;
     }
 }
 
+print_it($F, 'Loading "RWBY_Faces.png" For Image Flip Tests','FFFF00FF');
+
 $image = $F->load_image(
     {
         'x'      => 0,
         'y'      => $F->{'Y_CLIP'},
         'width'  => $XX,
         'height' => ($YY - $F->{'Y_CLIP'}),
-       'file'   => 'images/RWBY_Faces.png'
+       'file'   => "$images_path/RWBY_Faces.png"
     }
 );
 $s = time + $factor;
 $angle = 0; # Just re-using this variable
 while (time < $s) {
-    foreach my $dir (qw(normal horizontal normal vertical normal both)) {
+    foreach my $dir (qw(normal horizontal vertical both)) {
         my $rot = $F->blit_transform(
             {
                 'flip'      => $dir,
@@ -690,7 +699,7 @@ while (time < $s) {
         );
         $rot->{'x'} = abs(($XX - $rot->{'width'})  / 2);
         $rot->{'y'} = abs((($YY - $F->{'Y_CLIP'}) - $rot->{'height'}) / 2);
-        print_it($F, "Testing Image flip $dir");
+        print_it($F, "Testing Image Flip $dir");
         $F->blit_write($rot);
         sleep .3;
     }
@@ -717,8 +726,8 @@ while (time < $s) {
 }
 
 {
-    print_it($F,'Testing Animated Images.  Loading...');
-    opendir(my $DIR,'images/');
+    print_it($F,'Testing Animated Images.  Loading...','FFFF00FF');
+    opendir(my $DIR,$images_path);
     chomp(my @list = readdir($DIR));
     closedir($DIR);
     @list = shuffle(@list);
@@ -726,20 +735,20 @@ while (time < $s) {
         next unless ($info =~ /\.gif$/i);
         for $angle (0 .. 1) {
             if ($angle || $XX <= 320) {
-                print_it($F, "Loading Animated Image '$info' Scaled to Full Screen");
+                print_it($F, "Loading Animated Image '$info' Scaled to Full Screen",'FFFF00FF');
                 $image = $F->load_image(
                     {
                         'width'  => $XX,
                         'height' => $YY - $F->{'Y_CLIP'},
-                        'file'   => "images/$info",
+                        'file'   => "$images_path/$info",
                         'center' => 3
                     }
                 );
             } else {
-                print_it($F, "Loading Animated Image '$info' Native Size");
+                print_it($F, "Loading Animated Image '$info' Native Size",'FFFF00FF');
                 $image = $F->load_image(
                     {
-                        'file'   => "images/$info",
+                        'file'   => "$images_path/$info",
                         'center' => 3
                     }
                 );
@@ -757,7 +766,7 @@ while (time < $s) {
                     $s = time + ($factor);
                     while (time <= $s) {
                         foreach my $frame (0 .. (scalar(@{$image}) - 1)) {
-                            if (time > ($s * 3)) {
+                            if (time > $s * 2) {
                                 print_it($F, 'Your System is Too Slow To Complete The Animation','FF9999FF');
                                 sleep 2;
                                 last;
@@ -784,7 +793,6 @@ while (time < $s) {
     }
 }
 
-
 {
     print_it($F, 'Testing OR Drawing Mode');
 
@@ -794,8 +802,10 @@ while (time < $s) {
 
     $F->set_color({'red' => 255, 'green' => 0, 'blue' => 0});
     $F->circle({'x' => $mid - ($size / 2),'y'=> $F->{'Y_CLIP'} + $size*2,'radius' => $size, 'filled' => 1});
+    sleep .1;
     $F->set_color({'red' => 0, 'green' => 255, 'blue' => 0});
     $F->circle({'x' => $mid,'y'=> $F->{'Y_CLIP'} + $size,'radius' => $size, 'filled' => 1});
+    sleep .1;
     $F->set_color({'red' => 0, 'green' => 0, 'blue' => 255});
     $F->circle({'x' => $mid + ($size / 2),'y'=> $F->{'Y_CLIP'} + $size * 2,'radius' => $size, 'filled' => 1});
     sleep $factor;
@@ -808,8 +818,10 @@ while (time < $s) {
 
     $F->set_color({'red' => 0, 'green' => 255, 'blue' => 255});
     $F->rbox({'x' => 0,'y' => 0, 'width'=> ($XX / 2),'height' => ($YY / 2),'filled' => 1});
+    sleep .1;
     $F->set_color({'red' => 255, 'green' => 0, 'blue' => 255});
     $F->rbox({'x' => $XX / 4,'y' => $YY / 4, 'width'=> ($XX / 2),'height' => ($YY / 2),'filled' => 1});
+    sleep .1;
     $F->set_color({'red' => 255, 'green' => 255, 'blue' => 0});
     $F->rbox({'x' => ($XX / 2),'y' => ($YY / 2), 'width'=> ($XX / 2),'height' => ($YY / 2),'filled' => 1});
     sleep $factor;
@@ -824,10 +836,13 @@ while (time < $s) {
     my $size = int(($YY - $F->{'Y_CLIP'}) / 3);
     my $mid  = int($XX / 2);
 
+    sleep .1;
     $F->set_color({'red' => 255, 'green' => 0, 'blue' => 0});
     $F->circle({'x' => $mid - ($size / 2),'y'=> $F->{'Y_CLIP'} + $size*2,'radius' => $size, 'filled' => 1});
+    sleep .1;
     $F->set_color({'red' => 0, 'green' => 255, 'blue' => 0});
     $F->circle({'x' => $mid,'y'=> $F->{'Y_CLIP'} + $size,'radius' => $size, 'filled' => 1});
+    sleep .1;
     $F->set_color({'red' => 0, 'green' => 0, 'blue' => 255});
     $F->circle({'x' => $mid + ($size / 2),'y'=> $F->{'Y_CLIP'} + $size * 2,'radius' => $size, 'filled' => 1});
     sleep $factor;
@@ -840,9 +855,9 @@ while (time < $s) {
         {
             'x'      => 0,
             'y'      => $F->{'Y_CLIP'},
-            'width'  => $XX/2,
-            'height' => $h/2,
-            'file'   => 'images/GFB.png',
+            'width'  => ($XX<=320) ? $XX : $XX/2,
+            'height' => ($XX<=320) ? $h : $h/2,
+            'file'   => "$images_path/GFB.png",
             'center' => 3
         }
     );
@@ -850,9 +865,9 @@ while (time < $s) {
         {
             'x'      => 0,
             'y'      => $F->{'Y_CLIP'},
-            'width'  => $XX/2,
-            'height' => $h/2,
-            'file'   => 'images/RWBY_beuowolf.jpg',
+            'width'  => ($XX<=320) ? $XX : $XX/2,
+            'height' => ($XX<=320) ? $h : $h/2,
+            'file'   => "$images_path/RWBY_beuowolf.jpg",
             'center' => 3,
             'convertalpha' => 1
         }
@@ -886,9 +901,9 @@ while (time < $s) {
         {
             'x'      => 0,
             'y'      => $F->{'Y_CLIP'},
-            'width'  => $XX/2,
-            'height' => $h/2,
-            'file'   => 'images/RWBY_beuowolf.jpg',
+            'width'  => ($XX<=320) ? $XX : $XX/2,
+            'height' => ($XX<=320) ? $h : $h/2,
+            'file'   => "$images_path/RWBY_beuowolf.jpg",
             'center' => 3,
             'convertalpha' => 1
         }
@@ -897,9 +912,9 @@ while (time < $s) {
         {
             'x'      => 0,
             'y'      => $F->{'Y_CLIP'},
-            'width'  => $XX/2,
-            'height' => $h/2,
-            'file'   => 'images/RWBY_Alternate_Logo.png',
+            'width'  => ($XX<=320) ? $XX : $XX/2,
+            'height' => ($XX<=320) ? $h : $h/2,
+            'file'   => "$images_path/RWBY_Alternate_Logo.png",
             'center' => 3
         }
     );
@@ -927,13 +942,6 @@ while (time < $s) {
 $F->clip_reset();
 $F->cls('ON');
 
-print STDERR qq{
-
-Yes, I happen to absolutely enjoy the RWBY Anime Series
-by Rooster Teeth Productions, a purely American Anime.
-
-};
-
 exit(0);
 
 sub print_it {
@@ -950,17 +958,17 @@ sub print_it {
         my $b = $fb->ttf_print(
             {
                 'x'            => 5 * $xm,
-                  'y'            => max(9, 20 * $ym),
-                  'height'       => max(10, 20 * $ym),
-                  'color'        => $color,
-                  'text'         => $message,
-                  'bounding_box' => 1,
-                  'center'       => $fb->{'CENTER_X'},
-                  'antialias'    => 1
+                'y'            => max(9, 15 * $ym),
+                'height'       => max(9, 20 * $ym),
+                'color'        => $color,
+                'text'         => $message,
+                'bounding_box' => 1,
+                'center'       => $fb->{'CENTER_X'},
+                'antialias'    => 1
             }
         );
         $fb->ttf_print($b);
-        $fb->clip_set({'x' => 0, 'y' => $b->{'pheight'}, 'xx' => $XX, 'yy' => $YY});
+        $fb->clip_set({'x' => 0, 'y' => $b->{'pheight'} * .75, 'xx' => $XX, 'yy' => $YY});
         $center_y = (($YY - $b->{'pheight'}) / 2) + $b->{'pheight'};
         $fb->normal_mode();
     } else {
