@@ -295,18 +295,11 @@ sub arctype {
 
 sub finish {
     $RUNNING = 0;
-    print locate(1, 1), "WAITING FOR THREADS TO FINISH...";
-    while (threads->list(threads::running)) {
-        threads->yield();
-    }
-    print locate(1, 1), clline, "Shutting down...\n";
-    foreach my $thr (threads->list(threads::joinable)) {
-        $thr->join;
+    print locate(1, 1), "SHUTTING DOWN THREADS...";
+    foreach my $thr (threads->list()) {
+        $thr->detach();
     }
     sleep 1;
-    foreach my $p (0 .. $Threads) {
-        $framebuffer[$p]->cls();
-    }
     cls;
     exec('reset');
 } ## end sub finish
